@@ -9,7 +9,6 @@ use {
 
 #[derive(Accounts)]
 #[instruction(
-    owner: Pubkey,
     namespace: String,
     bump: u8,
 )]
@@ -18,7 +17,7 @@ pub struct CreateIndex<'info> {
         init, 
         seeds = [
             state::SEED_INDEX, 
-            owner.as_ref(), 
+            signer.key().as_ref(), 
             namespace.as_ref()
         ], 
         bump = bump, 
@@ -36,16 +35,16 @@ pub struct CreateIndex<'info> {
 
 pub fn handler(
     ctx: Context<CreateIndex>, 
-    owner: Pubkey,
     namespace: String,
     bump: u8,
 ) -> ProgramResult {
     // Get accounts.
     let index = &mut ctx.accounts.index;
+    let signer = &ctx.accounts.signer;
 
     // Initialize index account.
     index.namespace = namespace;
-    index.owner = owner;
+    index.owner = signer.key();
     index.item_count = 0;
     index.bump = bump;
     
