@@ -9,13 +9,8 @@ declare_id!("Fg6PaFpoGXkYsidMpWTK6W2BeZ7FEfcYkg476zPFsLnS");
 pub mod indexor {
     use super::*;
 
-    pub fn create_index(
-        ctx: Context<CreateIndex>,
-        owner: Pubkey,
-        namespace: String,
-        bump: u8,
-    ) -> ProgramResult {
-        create_index::handler(ctx, owner, namespace, bump)
+    pub fn create_index(ctx: Context<CreateIndex>, namespace: String, bump: u8) -> ProgramResult {
+        create_index::handler(ctx, namespace, bump)
     }
 
     pub fn create_item(
